#!/bin/sh

# update platinun configuration

DIRECTORY=$(cd `dirname $0`; pwd)

RUNLOG_FILE="${DIRECTORY}/.run_log"

get_speed_limit()
{
	local speed=`grep "MaxUploadSpeed=" ${DIRECTORY}/conf/server.ini | awk -F= '{ print $2 }'`
	if [ -n "${speed}" ]; then
		echo ${speed}
	else
		exit 1
	fi
}

set_speed_limit()
{
	local speed=$1

	echo "set speed limit to ${speed}" >> ${RUNLOG_FILE}

	sed -i "s/MaxUploadSpeed=.*/MaxUploadSpeed=${speed}/g" ${DIRECTORY}/conf/server.ini

	if [ $? -ne 0 ]; then
		echo "set speed limit failed" >> ${RUNLOG_FILE}
		exit 1
	fi

	${DIRECTORY}/stop.sh > /dev/null 2>&1

	${DIRECTORY}/start.sh > /dev/null 2>&1
}

get_cache_size()
{
	local size=`grep "MaxDiskUsageGB=" ${DIRECTORY}/conf/server.ini | awk -F= '{ print $2 }'`
	if [ -n "${size}" ]; then
		echo ${size}
	else
		exit 1
	fi
}

set_cache_size()
{
	local size=$1
	
	echo "set cache size to ${size}" >> ${RUNLOG_FILE}

	sed -i "s/MaxDiskUsageGB=.*/MaxDiskUsageGB=${size}/g" ${DIRECTORY}/conf/server.ini

	if [ $? -ne 0 ]; then
		echo "set cache size failed" >> ${RUNLOG_FILE}
		exit 1
	fi

	${DIRECTORY}/stop.sh > /dev/null 2>&1

	${DIRECTORY}/start.sh > /dev/null 2>&1
}

while getopts ":sS:cC:" option
do
	case $option in
		s)
			# get speed limit
			get_speed_limit
			;;
		S)
			# set speed limit
			set_speed_limit $OPTARG
			;;
		c)
			# get cache size
			get_cache_size
			;;
		C)
			# set cache size
			set_cache_size $OPTARG
			;;
		?)
			# invalid
			exit 1
			;;
		*)
			exit 1
			;;
	esac
done

