#!/bin/sh

curr_dir=$(cd `dirname $0`; pwd)
sys_dir="${curr_dir}/../system"
tmp_dir="/tmp/.xyapp"
log_file="${tmp_dir}/xyipk.log"

mon_name="xyipk_monitor"
mon_path="${curr_dir}/${mon_name}"

snfile="/tmp/.efuse_sn"
snprefix="QHRM"
sn=

if [ ! -f ${tmp_dir} ]; then
	mkdir -p ${tmp_dir}
fi

log()
{
	local time=`date "+%Y-%m-%d %H:%M:%S"`
	echo "${time} <pid $$> $*" >> ${log_file}
}

ARG_SN=
ARG_CACHE=
ARG_TD=
ARG_TK=

parse_args()
{
	while getopts "n:c:d:t:" option
	do
		case $option in
			n)
				log "read arg sn $OPTARG"
				ARG_SN=$OPTARG
				;;
			c)
				log "read arg cache dir $OPTARG"
				ARG_CACHE=$OPTARG
				;;
			d)
				log "read arg download dir $OPTARG"
				ARG_TD=$OPTARG
				;;
			t)
				log "read arg token dir $OPTARG"
				ARG_TK=$OPTARG
				;;
			*)
				log "ignore arg $option $OPTARG"
				;;
		esac
	done

	if [ -z "${ARG_SN}" -o -z "${ARG_CACHE}" -o -z "${ARG_TD}" -o -z "${ARG_TK}" ]; then
		log "invalid arguments"
		exit 1
	fi
}

datadir_config()
{
	local datadir=$1
	local datadir_dir="${sys_dir}/etc"
	local datadir_etc="${datadir_dir}/datadir.conf"
	if [ -f ${datadir_etc}  ]; then
		local olddir=`cat ${datadir_etc}`
		if [ $? -eq 0 -a "${olddir}" = "${datadir}"  ]; then
			return 0
		fi
	fi
	mkdir -p ${datadir_dir}
	log "update data dir config to '${datadir}'"
	echo -n "${datadir}" > ${datadir_etc}
}

etm_config()
{
	mkdir -p ${sys_dir}/etc
	if [ $? -ne 0 ]; then
		log "mk dir ${sys_dir}/etc failed"
		return 1
	fi

	local etm_cfg=${sys_dir}/etc/etm.cfg
	echo "SN=${sn}" > ${etm_cfg}
	echo "TD=${ARG_TD}" >> ${etm_cfg}
	echo "TK=${ARG_TK}" >> ${etm_cfg}
}

parse_args $@
datadir_config ${ARG_CACHE}

sn="${snprefix}${ARG_SN}"
oldsn=`cat ${snfile}`
if [ "${oldsn}" != "${sn}" ]; then
	log "try set sn to '${sn}'"
	echo -n "${sn}" > ${snfile}
	if [ $? -ne 0 ]; then
		log "update sn failed"
		exit 1
	fi
fi

etm_config

monitor_pids=`ps -ef | grep ${mon_name} | grep -v grep | awk '{ printf $2 " " }'`

if [ -z "${monitor_pids}" ]; then
	# start monitor
	log "start xyipk monitor"
	${mon_path} > /dev/null 2>&1 &
fi

